bayespy.inference.vmp.nodes.dirichlet.DirichletDistribution.compute_cgf_from_parents
====================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.dirichlet

.. automethod:: DirichletDistribution.compute_cgf_from_parents